def main():
    import sys
    from PyQt6 import QtWidgets
    from xrdPlanner.classes import MainWindow
    app = QtWidgets.QApplication(sys.argv)
    main = MainWindow()
    main.show()
    sys.exit(app.exec())
    
if __name__ == '__main__':
    main()



__version__ = '1.8.1'
__author__ = 'Lennard Krause'
__authors__ = ['Lennard Krause', 'Frederik H. Gjørup', 'Mads R. V. Jørgensen']
__email__ = 'lkrause@chem.au.dk'
__date__ = '30.05.2024'
__year__ = '2024'